@@ -4,7 +4,7 @@ __author__ = r'wsb310@gmail.com'
 
 from hagworm.frame.fastapi.base import APIRouter
 
-from controller import home
+from . import home
 
 
 router = APIRouter(prefix=r'/demo')
