@@ -5,6 +5,8 @@ __author__ = r'wsb310@gmail.com'
 from hagworm.frame.fastapi.base import APIRouter, Request
 from hagworm.frame.fastapi.response import ErrorResponse
 
+from service import DataSource
+
 
 router = APIRouter()
 
@@ -12,7 +14,7 @@ router = APIRouter()
 @router.get(r'/')
 async def default(request: Request):
 
-    return request.client_ip
+    return request.client_ip, DataSource().timestamp_ms
 
 
 @router.get(r'/error')
