@@ -2,11 +2,33 @@
 
 __author__ = r'wsb310@gmail.com'
 
+import os
+
 from hagworm.extend.base import Utils
 from hagworm.extend.config import Configure, Field, HostType, StrListType
 
 
-class _Static(Configure):
+class _Config(Configure):
+
+    Port: int = Field(r'Base')
+    Debug: bool = Field(r'Base')
+    GZip: bool = Field(r'Base')
+    Secret: str = Field(r'Base')
+    ProcessNum: int = Field(r'Base')
+    ServerName: str = Field(r'Base')
+
+    AllowOrigins: StrListType = Field(r'Cros')
+    AllowMethods: StrListType = Field(r'Cros')
+    AllowHeaders: StrListType = Field(r'Cros')
+    AllowCredentials: bool = Field(r'Cros')
+
+    LogLevel: str = Field(r'Log')
+    LogFilePath: str = Field(r'Log')
+    LogFileSplitSize: int = Field(r'Log')
+    LogFileSplitTime: str = Field(r'Log')
+    LogFileBackups: int = Field(r'Log')
+
+    ThreadPoolMaxWorkers: int = Field(r'ThreadPool')
 
     MySqlMasterServer: HostType = Field(r'MySql')
     MySqlSlaveServer: HostType = Field(r'MySql')
@@ -33,37 +55,12 @@ class _Static(Configure):
     RedisKeyPrefix: str = Field(r'Redis')
 
 
-class _Dynamic(Configure):
+Config = _Config()
 
-    Port: int = Field(r'Base')
-    Debug: bool = Field(r'Base')
-    GZip: bool = Field(r'Base')
-    Secret: str = Field(r'Base')
-    ProcessNum: int = Field(r'Base')
-    ServerName: str = Field(r'Base')
+cluster = Utils.getenv(r'CLUSTER', r'').strip().lower()
+current_path = os.path.split(os.path.abspath(__file__))[0]
 
-    AllowOrigins: StrListType = Field(r'Cros')
-    AllowMethods: StrListType = Field(r'Cros')
-    AllowHeaders: StrListType = Field(r'Cros')
-    AllowCredentials: bool = Field(r'Cros')
-
-    LogLevel: str = Field(r'Log')
-    LogFilePath: str = Field(r'Log')
-    LogFileSplitSize: int = Field(r'Log')
-    LogFileSplitTime: str = Field(r'Log')
-    LogFileBackups: int = Field(r'Log')
-
-    ThreadPoolMaxWorkers: int = Field(r'ThreadPool')
-
-
-ConfigStatic = _Static()
-ConfigDynamic = _Dynamic()
-
-cluster = Utils.getenv(r'CLUSTER', None)
-
-if cluster is None:
-    ConfigStatic.read(r'./config/static.conf')
-    ConfigDynamic.read(r'./config/dynamic.conf')
+if cluster:
+    Config.read_yaml(os.path.join(current_path, f'./config/config.{cluster}.yaml'))
 else:
-    ConfigStatic.read(f'./config/static.{cluster.lower()}.conf')
-    ConfigDynamic.read(f'./config/dynamic.{cluster.lower()}.conf')
+    Config.read_yaml(os.path.join(current_path, r'./config/config.yaml'))
