@@ -14,7 +14,7 @@ from hagworm.frame.stress_tests import Launcher, RunnerAbstract, TimerMS
 
 class Runner(RunnerAbstract):
 
-    async def _run(self):
+    async def _execute(self):
 
         for index in range(5):
 
@@ -23,10 +23,10 @@ class Runner(RunnerAbstract):
                 with TimerMS() as timer:
                     await Utils.sleep(Utils.randint(10, 99) / 1000)
 
-                if Utils.randhit([True, False], [50, 50]):
-                    self.success(f'Test{index}', timer.value)
+                if Utils.rand_hit([True, False], [50, 50]):
+                    await self.success(f'Test{index}', timer.value)
                 else:
-                    self.failure(f'Test{index}', timer.value)
+                    await self.failure(f'Test{index}', timer.value)
 
 
 if __name__ == r'__main__':
