@@ -2,11 +2,12 @@
 
 __author__ = r'wsb310@gmail.com'
 
+import typing
+
 import os
 import re
 import sys
 import platform
-import traceback
 import uuid
 import time
 import math
@@ -15,7 +16,6 @@ import random
 import hashlib
 import base64
 import hmac
-import urllib
 import textwrap
 import itertools
 import copy
@@ -39,16 +39,18 @@ import xmltodict
 import xml.dom.minidom
 
 from datetime import datetime, timedelta
-from contextlib import closing
+from contextlib import closing, suppress
 from collections import OrderedDict
 from collections.abc import Iterable
 from cachetools import cached, TTLCache
+from urllib.parse import urlparse
 from zipfile import ZipFile, ZIP_DEFLATED
 
 from stdnum import luhn
 from dateutil.parser import parse as date_parse
 
 from .text import StrUtils
+from .. import hagworm_slogan
 
 
 class Utils:
@@ -64,6 +66,8 @@ class Utils:
 
     _FALSE_VALUES = (r'null', r'none', r'nil', r'false', r'0', r'', False, 0,)
 
+    log = loguru.logger
+
     math = math
     random = random
     textwrap = textwrap
@@ -71,9 +75,7 @@ class Utils:
 
     path = os.path
 
-    log = loguru.logger
-    urlparse = urllib.parse
-
+    urlparse = staticmethod(urlparse)
     deepcopy = staticmethod(copy.deepcopy)
 
     func_wraps = staticmethod(functools.wraps)
@@ -88,31 +90,42 @@ class Utils:
 
     date_parse = staticmethod(date_parse)
 
-    @classmethod
-    def get_class_name(cls, val):
+    suppress = staticmethod(suppress)
 
+    @staticmethod
+    def get_class_name(val: typing.Type) -> str:
         return f'{val.__module__}.{val.__name__}'
 
-    @classmethod
-    def environment(cls):
+    @staticmethod
+    def environment() -> typing.Dict:
 
         return {
             r'python': sys.version,
             r'system': [platform.system(), platform.release(), platform.version(), platform.machine()],
         }
 
-    @classmethod
-    def deprecation_warning(cls, val):
+    @staticmethod
+    def print_slogan():
 
+        environment = Utils.environment()
+
+        Utils.log.info(
+            f'{hagworm_slogan}'
+            f'python {environment["python"]}\n'
+            f'system {" ".join(environment["system"])}'
+        )
+
+    @staticmethod
+    def deprecation_warning(val: str):
         warnings.warn(val, DeprecationWarning)
 
     @classmethod
-    def get_node_id(cls):
+    def get_node_id(cls) -> str:
 
         return cls.md5(f'{cls.getpid()}@{uuid.getnode()}')
 
     @classmethod
-    def utf8(cls, val):
+    def utf8(cls, val: typing.AnyStr) -> bytes:
 
         if isinstance(val, cls._BYTES_TYPES):
             return val
@@ -125,20 +138,23 @@ class Utils:
         )
 
     @classmethod
-    def basestring(cls, val):
+    def basestring(cls, val: typing.AnyStr) -> str:
 
-        if isinstance(val, cls._STRING_TYPES):
+        type_ = type(val)
+
+        if type_ in cls._STRING_TYPES:
             return val
-
-        if isinstance(val, bytes):
+        elif type_ is bytes:
             return val.decode(r'utf-8')
-
-        raise TypeError(
-            r'Expected str, bytes, or None; got %r' % type(val)
-        )
+        else:
+            raise TypeError(f'Expected str, bytes, or None; got {type_}')
 
     @classmethod
-    def vague_string(cls, val, vague_str=r'*', vague_len=0.5, min_vague=1, max_vague=10):
+    def vague_string(
+            cls, val: str,
+            vague_str: str = r'*', vague_len: float = 0.5,
+            min_vague: int = 1, max_vague: int = 10
+    ):
 
         val_len = len(val)
         vague_len = max(min_vague, min(max_vague, cls.math.ceil(val_len * vague_len)))
@@ -148,89 +164,86 @@ class Utils:
 
         return val[:l_show] + vague_str * vague_len + val[val_len - r_show:]
 
-    @classmethod
-    def json_encode(cls, val, **kwargs):
-
+    @staticmethod
+    def json_encode(val: typing.Any, **kwargs):
         return ujson.dumps(val, **kwargs)
 
     @classmethod
-    def json_decode(cls, val, **kwargs):
-
+    def json_decode(cls, val: typing.AnyStr, **kwargs):
         return ujson.loads(cls.basestring(val), **kwargs)
 
-    @classmethod
-    def msgpack_encode(cls, val, **kwargs):
-
+    @staticmethod
+    def msgpack_encode(val: typing.Any, **kwargs):
         return msgpack.dumps(val, **kwargs)
 
-    @classmethod
-    def msgpack_decode(cls, val, **kwargs):
-
+    @staticmethod
+    def msgpack_decode(val: typing.AnyStr, **kwargs):
         return msgpack.loads(val, **kwargs)
 
-    @classmethod
-    def today(cls):
+    @staticmethod
+    def today() -> datetime:
 
         result = datetime.now()
 
         return result.replace(hour=0, minute=0, second=0, microsecond=0)
 
-    @classmethod
-    def yesterday(cls):
+    @staticmethod
+    def yesterday() -> datetime:
 
         result = datetime.now() - timedelta(days=1)
 
         return result.replace(hour=0, minute=0, second=0, microsecond=0)
 
-    @classmethod
-    def localnow(cls):
+    @staticmethod
+    def localnow() -> datetime:
 
         result = datetime.now()
 
         return result.replace(second=0, microsecond=0)
 
-    @classmethod
-    def localnow_on_hour(cls):
+    @staticmethod
+    def localnow_on_hour() -> datetime:
 
         result = datetime.now()
 
         return result.replace(minute=0, second=0, microsecond=0)
 
-    @classmethod
-    def utcnow(cls):
+    @staticmethod
+    def utcnow() -> datetime:
 
         result = datetime.utcnow()
 
         return result.replace(second=0, microsecond=0)
 
-    @classmethod
-    def utcnow_on_hour(cls):
+    @staticmethod
+    def utcnow_on_hour() -> datetime:
 
         result = datetime.utcnow()
 
         return result.replace(minute=0, second=0, microsecond=0)
 
-    @classmethod
-    def timestamp(cls, msec=False):
+    @staticmethod
+    def timestamp() -> int:
+        return int(time.time())
 
-        if msec:
-            return int(time.time() * 1000)
-        else:
-            return int(time.time())
+    @staticmethod
+    def timestamp_ms() -> int:
+        return int(time.time() * 1000)
 
     @classmethod
-    def convert_bool(cls, val):
+    def convert_bool(cls, val: typing.Any) -> bool:
 
         if isinstance(val, str):
             val = val.lower()
 
         return val not in cls._FALSE_VALUES
 
-    @classmethod
-    def convert_int(cls, val, default=0):
+    @staticmethod
+    def convert_int(val: typing.Any, default: int = 0) -> int:
 
         result = default
 
+        # noinspection PyBroadException
         try:
             if not isinstance(val, float):
                 result = int(val)
@@ -239,11 +252,12 @@ class Utils:
 
         return result
 
-    @classmethod
-    def convert_float(cls, val, default=0.0):
+    @staticmethod
+    def convert_float(val: typing.Any, default: float = 0) -> float:
 
         result = default
 
+        # noinspection PyBroadException
         try:
             if not isinstance(val, float):
                 result = float(val)
@@ -252,8 +266,12 @@ class Utils:
 
         return result
 
-    @classmethod
-    def interval_limit(cls, val, min_val, max_val):
+    @staticmethod
+    def interval_limit(
+            val: typing.Union[int, float],
+            min_val: typing.Union[int, float],
+            max_val: typing.Union[int, float]
+    ) -> typing.Union[int, float]:
 
         result = val
 
@@ -266,14 +284,14 @@ class Utils:
         return result
 
     @classmethod
-    def split_float(cls, val, sep=r',', minsplit=0, maxsplit=-1):
+    def split_float(cls, val: str, sep: str = r',', min_split: int = 0, max_split: int = -1) -> typing.List[float]:
 
         result = [
-            float(item.strip()) for item in val.split(sep, maxsplit)
+            float(item.strip()) for item in val.split(sep, max_split)
             if cls.re_match(r'[\d\.]+', item.strip().lstrip(r'-'))
         ]
 
-        fill = minsplit - len(result)
+        fill = min_split - len(result)
 
         if fill > 0:
             result.extend(0 for _ in range(fill))
@@ -281,33 +299,33 @@ class Utils:
         return result
 
     @classmethod
-    def join_float(cls, iterable, sep=r','):
+    def join_float(cls, val: typing.Iterable, sep: str = r',') -> str:
 
         result = []
 
-        for item in iterable:
+        for _v in val:
 
-            _type = type(item)
+            _type = type(_v)
 
             if _type is float:
 
-                result.append(str(item))
+                result.append(str(_v))
 
             elif _type is str:
 
-                item = item.strip()
+                _v = _v.strip()
 
-                if cls.re_match(r'[\d\.]+', item):
-                    result.append(item)
+                if cls.re_match(r'[\d\.]+', _v):
+                    result.append(_v)
 
         return sep.join(result)
 
     @classmethod
-    def split_int(cls, val, sep=r',', minsplit=0, maxsplit=-1):
+    def split_int(cls, val: str, sep: str = r',', min_split: int = 0, max_split: int = -1) -> typing.List[int]:
 
-        result = [int(item.strip()) for item in val.split(sep, maxsplit) if item.strip().lstrip(r'-').isdigit()]
+        result = [int(item.strip()) for item in val.split(sep, max_split) if item.strip().lstrip(r'-').isdigit()]
 
-        fill = minsplit - len(result)
+        fill = min_split - len(result)
 
         if fill > 0:
             result.extend(0 for _ in range(fill))
@@ -315,57 +333,56 @@ class Utils:
         return result
 
     @classmethod
-    def join_int(cls, iterable, sep=r','):
+    def join_int(cls, val: typing.Iterable, sep: str = r',') -> str:
 
         result = []
 
-        for item in iterable:
+        for _v in val:
 
-            _type = type(item)
+            _type = type(_v)
 
             if _type is int:
 
-                result.append(str(item))
+                result.append(str(_v))
 
             elif _type is str:
 
-                item = item.strip()
+                _v = _v.strip()
 
-                if item.isdigit():
-                    result.append(item)
+                if _v.isdigit():
+                    result.append(_v)
 
         return sep.join(result)
 
     @classmethod
-    def split_str(cls, val, sep=r'|', minsplit=0, maxsplit=-1):
+    def split_str(cls, val: str, sep: str = r'|', min_split: int = 0, max_split: int = -1) -> typing.List[str]:
 
         if val:
-            result = [item.strip() for item in val.split(sep, maxsplit)]
+            result = [item.strip() for item in val.split(sep, max_split)]
         else:
             result = []
 
-        fill = minsplit - len(result)
+        fill = min_split - len(result)
 
         if fill > 0:
             result.extend(r'' for _ in range(fill))
 
         return result
 
-    @classmethod
-    def join_str(cls, iterable, sep=r'|'):
-
-        return sep.join(str(val).replace(sep, r'') for val in iterable)
+    @staticmethod
+    def join_str(val, sep=r'|') -> str:
+        return sep.join(str(_v).replace(sep, r'') for _v in val)
 
     @classmethod
-    def list_extend(cls, iterable, val):
+    def list_extend(cls, iterable: typing.List, val: typing.Any):
 
         if cls.is_iterable(val, True):
             iterable.extend(val)
         else:
             iterable.append(val)
 
-    @classmethod
-    def str_len(cls, str_val):
+    @staticmethod
+    def str_len(str_val: str) -> int:
 
         result = 0
 
@@ -378,15 +395,15 @@ class Utils:
 
         return result
 
-    @classmethod
-    def sub_str(cls, str_val, length, suffix=r'...'):
+    @staticmethod
+    def sub_str(val: str, length: int, suffix: str = r'...') -> str:
 
         result = []
         strlen = 0
 
-        for val in str_val:
+        for _v in val:
 
-            if unicodedata.east_asian_width(val) in (r'A', r'F', r'W'):
+            if unicodedata.east_asian_width(_v) in (r'A', r'F', r'W'):
                 strlen += 2
             else:
                 strlen += 1
@@ -398,22 +415,22 @@ class Utils:
 
                 break
 
-            result.append(val)
+            result.append(_v)
 
         return r''.join(result)
 
     @classmethod
-    def re_match(cls, pattern, value):
+    def re_match(cls, pattern: str, value: str) -> bool:
 
         result = re.match(pattern, value)
 
         return True if result else False
 
     @classmethod
-    def randhit(cls, iterable, prob):
+    def rand_hit(cls, val: typing.List, prob: typing.Union[typing.List, typing.Callable]) -> typing.Any:
 
         if callable(prob):
-            prob = [prob(val) for val in iterable]
+            prob = [prob(_v) for _v in val]
 
         prob_sum = sum(prob)
 
@@ -427,15 +444,16 @@ class Utils:
                 prob_hit += prob[index]
 
                 if prob_hit >= prob_sum:
-                    return iterable[index]
+                    return val[index]
 
-        return cls.random.choice(iterable)
+        return cls.random.choice(val)
 
     @classmethod
-    def urandom_seed(cls):
+    def urandom_seed(cls) -> int:
 
         seed_num = None
 
+        # noinspection PyBroadException
         try:
 
             with open(r'/dev/urandom', r'rb') as f:
@@ -449,10 +467,11 @@ class Utils:
         return seed_num
 
     @classmethod
-    def read_urandom(cls, size):
+    def read_urandom(cls, size: int) -> typing.AnyStr:
 
         result = None
 
+        # noinspection PyBroadException
         try:
 
             with open(r'/dev/urandom', r'rb') as f:
@@ -464,46 +483,50 @@ class Utils:
 
         return result
 
-    @classmethod
-    def get_host_ip(cls):
-
-        result = None
+    @staticmethod
+    def get_host_ip() -> str:
 
         with closing(socket.socket(socket.AF_INET, socket.SOCK_DGRAM)) as _socket:
             _socket.connect((r'223.5.5.5', 53))
-            result = _socket.getsockname()[0]
+            return _socket.getsockname()[0]
 
-        return result
-
-    @classmethod
-    def ip2int(cls, val):
+    @staticmethod
+    def ip2int(val: str) -> int:
 
         try:
             return int(binascii.hexlify(socket.inet_aton(val)), 16)
         except socket.error:
             return int(binascii.hexlify(socket.inet_pton(socket.AF_INET6, val)), 16)
 
-    @classmethod
-    def int2ip(cls, val):
+    @staticmethod
+    def int2ip(val: int) -> str:
 
         try:
             return socket.inet_ntoa(binascii.unhexlify(r'%08x' % val))
         except socket.error:
             return socket.inet_ntop(socket.AF_INET6, binascii.unhexlify(r'%032x' % val))
 
-    @classmethod
-    def time2stamp(cls, time_str, format_type=r'%Y-%m-%d %H:%M:%S', timezone=None):
+    @staticmethod
+    def time2stamp(
+            time_str: str,
+            format_type: str = r'%Y-%m-%d %H:%M:%S',
+            timezone: typing.Optional[str] = None
+    ) -> int:
 
         if timezone is None:
             return int(datetime.strptime(time_str, format_type).timestamp())
         else:
             return int(datetime.strptime(time_str, format_type).replace(tzinfo=pytz.timezone(timezone)).timestamp())
 
-    @classmethod
-    def stamp2time(cls, time_int=None, format_type=r'%Y-%m-%d %H:%M:%S', timezone=None):
+    @staticmethod
+    def stamp2time(
+            time_int: typing.Optional[int] = None,
+            format_type: str = r'%Y-%m-%d %H:%M:%S',
+            timezone: typing.Optional[str] = None
+    ) -> str:
 
         if time_int is None:
-            time_int = cls.timestamp()
+            time_int = int(time.time())
 
         if timezone is None:
             return time.strftime(format_type, datetime.fromtimestamp(time_int).timetuple())
@@ -511,49 +534,49 @@ class Utils:
             return time.strftime(format_type, datetime.fromtimestamp(time_int, pytz.timezone(timezone)).timetuple())
 
     @classmethod
-    def radix24(cls, val, align=0):
+    def radix24(cls, val: int, align: int = 0) -> str:
 
         base = StrUtils.SAFE_STRING_BASE
 
         return cls.radix_n(val, base, 24, align)
 
     @classmethod
-    def radix24_to_10(cls, val):
+    def radix24_to_10(cls, val: str) -> int:
 
         base = StrUtils.SAFE_STRING_BASE
 
         return cls.radix_n_to_10(val, base, 24)
 
     @classmethod
-    def radix36(cls, val, align=0):
+    def radix36(cls, val: int, align: int = 0) -> str:
 
         base = string.digits + string.ascii_uppercase
 
         return cls.radix_n(val, base, 36, align)
 
     @classmethod
-    def radix36_to_10(cls, val):
+    def radix36_to_10(cls, val: str) -> int:
 
         base = string.digits + string.ascii_uppercase
 
         return cls.radix_n_to_10(val, base, 36)
 
     @classmethod
-    def radix62(cls, val, align=0):
+    def radix62(cls, val: int, align: int = 0) -> str:
 
         base = string.digits + string.ascii_letters
 
         return cls.radix_n(val, base, 62, align)
 
     @classmethod
-    def radix62_to_10(cls, val):
+    def radix62_to_10(cls, val: str) -> int:
 
         base = string.digits + string.ascii_letters
 
         return cls.radix_n_to_10(val, base, 62)
 
-    @classmethod
-    def radix_n(cls, val, base, radix, align=0):
+    @staticmethod
+    def radix_n(val: int, base: str, radix: int, align: int = 0) -> str:
 
         num = abs(int(val))
 
@@ -566,7 +589,7 @@ class Utils:
         return r'{0:0>{1:d}s}'.format(result, align)
 
     @classmethod
-    def radix_n_to_10(cls, val, base, radix):
+    def radix_n_to_10(cls, val: str, base: str, radix: int) -> int:
 
         result = 0
 
@@ -576,8 +599,8 @@ class Utils:
 
         return result
 
-    @classmethod
-    def xml_encode(cls, dict_val, root_tag=r'root'):
+    @staticmethod
+    def xml_encode(dict_val: typing.Dict, root_tag: str = r'root') -> xml.dom.minidom.Document:
 
         xml_doc = xml.dom.minidom.Document()
 
@@ -602,12 +625,11 @@ class Utils:
         return xml_doc
 
     @classmethod
-    def xml_decode(cls, val):
-
+    def xml_decode(cls, val: str) -> typing.Dict:
         return xmltodict.parse(cls.utf8(val))
 
     @classmethod
-    def b32_encode(cls, val, standard=False):
+    def b32_encode(cls, val: typing.AnyStr, standard: bool = False) -> str:
 
         val = cls.utf8(val)
 
@@ -619,7 +641,7 @@ class Utils:
         return cls.basestring(result)
 
     @classmethod
-    def b32_decode(cls, val, standard=False, for_bytes=False):
+    def b32_decode(cls, val: typing.AnyStr, standard: bool = False, for_bytes: bool = False) -> typing.AnyStr:
 
         val = cls.utf8(val)
 
@@ -630,15 +652,13 @@ class Utils:
             if num > 0:
                 val = val + b'=' * (8 - num)
 
-        result = base64.b32decode(val)
-
         if for_bytes:
-            return result
+            return base64.b32decode(val)
         else:
-            return cls.basestring(result)
+            return cls.basestring(base64.b32decode(val))
 
     @classmethod
-    def b64_encode(cls, val, standard=False):
+    def b64_encode(cls, val: typing.AnyStr, standard: bool = False, for_bytes: bool = False) -> typing.AnyStr:
 
         val = cls.utf8(val)
 
@@ -652,10 +672,13 @@ class Utils:
 
             result = result.rstrip(b'=')
 
-        return cls.basestring(result)
+        if not for_bytes:
+            result = cls.basestring(result)
+
+        return result
 
     @classmethod
-    def b64_decode(cls, val, standard=False, for_bytes=False):
+    def b64_decode(cls, val: typing.AnyStr, standard: bool = False, for_bytes: bool = False) -> typing.AnyStr:
 
         val = cls.utf8(val)
 
@@ -678,165 +701,117 @@ class Utils:
             return cls.basestring(result)
 
     @classmethod
-    def jwt_encode(cls, val, key, algorithms=r'HS256'):
+    def jwt_encode(cls, val: str, key: str, algorithms: str = r'HS256') -> str:
 
         result = jwt.encode(val, key, algorithms)
 
         return cls.basestring(result)
 
     @classmethod
-    def jwt_decode(cls, val, key, algorithms=[r'HS256']):
+    def jwt_decode(cls, val: str, key: str, algorithms: str = r'HS256') -> str:
 
         val = cls.utf8(val)
 
         return jwt.decode(val, key, algorithms)
 
-    @classmethod
-    def yaml_encode(cls, data, stream=None):
-
+    @staticmethod
+    def yaml_encode(data: typing.Any, stream: typing.Any = None):
         return yaml.safe_dump(data, stream)
 
-    @classmethod
-    def yaml_decode(cls, stream):
-
+    @staticmethod
+    def yaml_decode(stream: typing.Any) -> typing.Any:
         return yaml.safe_load(stream)
 
-    @classmethod
-    def pickle_dumps(cls, val):
+    @staticmethod
+    def pickle_dumps(val: typing.Any) -> bytes:
 
         stream = pickle.dumps(val)
 
-        result = zlib.compress(stream)
+        return zlib.compress(stream)
 
-        return result
-
-    @classmethod
-    def pickle_loads(cls, val):
+    @staticmethod
+    def pickle_loads(val: bytes) -> typing.Any:
 
         stream = zlib.decompress(val)
 
-        result = pickle.loads(stream)
-
-        return result
-
-    @classmethod
-    def uuid1(cls, node=None, clock_seq=None):
+        return pickle.loads(stream)
 
+    @staticmethod
+    def uuid1(node: typing.Optional[str] = None, clock_seq: typing.Optional[str] = None) -> str:
         return uuid.uuid1(node, clock_seq).hex
 
-    @classmethod
-    def uuid1_urn(cls, node=None, clock_seq=None):
-
+    @staticmethod
+    def uuid1_urn(node: typing.Optional[str] = None, clock_seq: typing.Optional[str] = None) -> str:
         return str(uuid.uuid1(node, clock_seq))
 
     @classmethod
-    def crc32(cls, val):
-
-        val = cls.utf8(val)
-
-        return binascii.crc32(val)
+    def crc32(cls, val: typing.AnyStr) -> int:
+        return binascii.crc32(cls.utf8(val))
 
     @classmethod
-    def md5(cls, val):
-
-        val = cls.utf8(val)
-
-        return hashlib.md5(val).hexdigest()
+    def md5(cls, val: typing.AnyStr) -> str:
+        return hashlib.md5(cls.utf8(val)).hexdigest()
 
     @classmethod
-    def md5_u32(cls, val):
-
-        val = cls.utf8(val)
-
-        return int(hashlib.md5(val).hexdigest(), 16) >> 96
+    def md5_u32(cls, val: typing.AnyStr) -> int:
+        return int(hashlib.md5(cls.utf8(val)).hexdigest(), 16) >> 96
 
     @classmethod
-    def md5_u64(cls, val):
-
-        val = cls.utf8(val)
-
-        return int(hashlib.md5(val).hexdigest(), 16) >> 64
+    def md5_u64(cls, val: typing.AnyStr) -> int:
+        return int(hashlib.md5(cls.utf8(val)).hexdigest(), 16) >> 64
 
     @classmethod
-    def sha1(cls, val):
-
-        val = cls.utf8(val)
-
-        return hashlib.sha1(val).hexdigest()
+    def sha1(cls, val: typing.AnyStr) -> str:
+        return hashlib.sha1(cls.utf8(val)).hexdigest()
 
     @classmethod
-    def sha256(cls, val):
-
-        val = cls.utf8(val)
-
-        return hashlib.sha256(val).hexdigest()
+    def sha256(cls, val: typing.AnyStr) -> str:
+        return hashlib.sha256(cls.utf8(val)).hexdigest()
 
     @classmethod
-    def sha512(cls, val):
-
-        val = cls.utf8(val)
-
-        return hashlib.sha512(val).hexdigest()
+    def sha512(cls, val: typing.AnyStr) -> str:
+        return hashlib.sha512(cls.utf8(val)).hexdigest()
 
     @classmethod
-    def hmac_md5(cls, key, msg, b64_std=False):
+    def hmac_md5(cls, key: typing.AnyStr, data: typing.AnyStr, b64_std: bool = False) -> str:
 
-        key = cls.utf8(key)
-        msg = cls.utf8(msg)
+        _hmac = hmac.new(cls.utf8(key), cls.utf8(data), r'md5').digest()
 
-        result = hmac.new(key, msg, r'md5').digest()
-
-        result = cls.b64_encode(result, b64_std)
-
-        return cls.basestring(result)
+        return cls.basestring(cls.b64_encode(_hmac, b64_std))
 
     @classmethod
-    def hmac_sha1(cls, key, msg, b64_std=False):
+    def hmac_sha1(cls, key: typing.AnyStr, data: typing.AnyStr, b64_std: bool = False) -> str:
 
-        key = cls.utf8(key)
-        msg = cls.utf8(msg)
+        _hmac = hmac.new(cls.utf8(key), cls.utf8(data), r'sha1').digest()
 
-        result = hmac.new(key, msg, r'sha1').digest()
+        return cls.basestring(cls.b64_encode(_hmac, b64_std))
 
-        result = cls.b64_encode(result, b64_std)
-
-        return cls.basestring(result)
-
-    @classmethod
-    def ordered_dict(cls, val=None):
+    @staticmethod
+    def ordered_dict(val: typing.Optional[typing.Dict] = None) -> OrderedDict:
 
         if val is None:
             return OrderedDict()
         else:
             return OrderedDict(sorted(val.items(), key=lambda x: x[0]))
 
-    @classmethod
-    def is_iterable(cls, obj, standard=False):
+    @staticmethod
+    def is_iterable(obj: typing.Any, standard: bool = False) -> bool:
 
         if standard:
-            result = isinstance(obj, Iterable)
+            return isinstance(obj, Iterable)
         else:
-            result = isinstance(obj, (list, tuple,))
-
-        return result
-
-    @classmethod
-    def luhn_valid(cls, val):
+            return isinstance(obj, (list, tuple,))
 
+    @staticmethod
+    def luhn_valid(val: str) -> bool:
         return luhn.is_valid(val)
 
-    @classmethod
-    def luhn_sign(cls, val):
+    @staticmethod
+    def luhn_sign(val: str) -> str:
+        return val + luhn.calc_check_digit(val)
 
-        result = None
-
-        if val.isdigit():
-            result = val + luhn.calc_check_digit(val)
-
-        return result
-
-    @classmethod
-    def identity_card(cls, val):
+    @staticmethod
+    def identity_card(val: str) -> bool:
 
         result = False
 
@@ -857,16 +832,16 @@ class Utils:
 
         return result
 
-    @classmethod
-    def params_join(cls, params, filters=None):
+    @staticmethod
+    def params_join(params: typing.Dict, excludes: typing.Optional[typing.List] = None) -> str:
 
-        if filters is not None:
-            params = {key: val for key, val in params.items() if key not in filters}
+        if excludes is not None:
+            params = {key: val for key, val in params.items() if key not in excludes}
 
         return r'&'.join(f'{key}={val}' for key, val in sorted(params.items(), key=lambda x: x[0]))
 
     @classmethod
-    def params_sign(cls, *args, **kwargs):
+    def params_sign(cls, *args, **kwargs) -> str:
 
         result = []
 
@@ -880,7 +855,7 @@ class Utils:
         return cls.md5(r'&'.join(result))
 
     @classmethod
-    def get_today_region(cls, today=None):
+    def get_today_region(cls, today: typing.Optional[datetime] = None) -> typing.Tuple[int, int]:
 
         if today is None:
             today = cls.today()
@@ -894,7 +869,7 @@ class Utils:
         return start_time, end_time
 
     @classmethod
-    def get_month_region(cls, today=None):
+    def get_month_region(cls, today: typing.Optional[datetime] = None) -> typing.Tuple[int, int]:
 
         if today is None:
             today = cls.today()
@@ -912,7 +887,7 @@ class Utils:
         return start_time, end_time
 
     @classmethod
-    def get_week_region(cls, today=None):
+    def get_week_region(cls, today: typing.Optional[datetime] = None) -> typing.Tuple[int, int]:
 
         if today is None:
             today = cls.today()
@@ -927,23 +902,22 @@ class Utils:
 
         return start_time, end_time
 
-    @classmethod
-    def zip_file(cls, zip_file, *file_paths):
+    @staticmethod
+    def zip_file(zip_file: str, *file_paths: str):
 
-        def _add_to_zip(zf, path, zippath):
+        def _add_to_zip(_zf: ZipFile, _path: str, _zip_path: str):
 
-            if os.path.isfile(path):
+            if os.path.isfile(_path):
 
-                zf.write(path, zippath, ZIP_DEFLATED)
+                _zf.write(_path, _zip_path, ZIP_DEFLATED)
 
-            elif os.path.isdir(path):
+            elif os.path.isdir(_path):
 
-                if zippath:
-                    zf.write(path, zippath)
+                if _zip_path:
+                    _zf.write(_path, _zip_path)
 
-                for nm in os.listdir(path):
-                    _add_to_zip(zf, os.path.join(path, nm),
-                                os.path.join(zippath, nm))
+                for nm in os.listdir(_path):
+                    _add_to_zip(_zf, os.path.join(_path, nm), os.path.join(_zip_path, nm))
 
         with ZipFile(zip_file, r'w') as _zf:
 
@@ -958,22 +932,21 @@ class Utils:
 
                 _add_to_zip(_zf, path, zippath)
 
-    @classmethod
-    def unzip_file(cls, zip_file, file_paths):
+    @staticmethod
+    def unzip_file(zip_file: str, file_paths: str):
 
         with ZipFile(zip_file, r'r') as _zf:
             _zf.extractall(file_paths)
 
-    @classmethod
+    @staticmethod
     @cached(cache=TTLCache(maxsize=0xf, ttl=1))
-    def get_cpu_percent(cls):
-
+    def get_cpu_percent() -> float:
         return psutil.cpu_percent()
 
-    @classmethod
-    def kill_process(cls, *args):
+    @staticmethod
+    def kill_process(*names):
 
-        process_names = [val.lower() for val in args]
+        process_names = [name.lower() for name in names]
 
         for pid in psutil.pids():
 
@@ -999,15 +972,15 @@ class FuncWrapper:
         for func in self._callables:
             try:
                 func(*args, **kwargs)
-            except:
-                Utils.log.error(traceback.format_exc())
+            except Exception as err:
+                Utils.log.exception(str(err))
 
     @property
-    def is_valid(self):
+    def is_valid(self) -> bool:
 
         return len(self._callables) > 0
 
-    def add(self, func):
+    def add(self, func: typing.Callable) -> bool:
 
         if func in self._callables:
             return False
@@ -1015,7 +988,7 @@ class FuncWrapper:
             self._callables.add(func)
             return True
 
-    def remove(self, func):
+    def remove(self, func: typing.Callable) -> bool:
 
         if func in self._callables:
             self._callables.remove(func)
