@@ -2,6 +2,8 @@
 
 __author__ = r'wsb310@gmail.com'
 
+import typing
+
 import os
 import sys
 
@@ -11,7 +13,7 @@ import py_compile
 from .base import Utils
 
 
-def compile(file_path, cfile_path=None, exclude=None):
+def compile_pyc(file_path: str, pyc_file_path: typing.Optional[str] = None, exclude: typing.Optional[str] = None):
     """PYC编译函数
     """
 
@@ -36,13 +38,13 @@ def compile(file_path, cfile_path=None, exclude=None):
                 if ext_name != r'.py':
                     continue
 
-                if cfile_path is None:
+                if pyc_file_path is None:
 
                     dest_path = file_path
 
                 else:
 
-                    dest_path = root.replace(file_path, cfile_path)
+                    dest_path = root.replace(file_path, pyc_file_path)
 
                     if not os.path.exists(dest_path):
                         os.makedirs(dest_path)
@@ -68,7 +70,7 @@ def main():
     args = parser.parse_args()
 
     try:
-        compile(args.input, args.output, args.exclude)
+        compile_pyc(args.input, args.output, args.exclude)
     except Exception as error:
         sys.stderr.write(f'{error}\n')
 
