@@ -4,34 +4,27 @@ __author__ = r'wsb310@gmail.com'
 
 import traceback
 
+from loguru import logger
 from contextlib import contextmanager
 
-from .base import Utils
 
-
-# 基础异常
-class BaseError(Exception):
-
-    def __init__(self, *args, **kwargs):
-
-        super().__init__(*args, **kwargs)
-
-
-class Ignore(BaseError):
+class Ignore(Exception):
     """可忽略的异常
 
     用于with语句块跳出，或者需要跳出多层逻辑的情况
 
     """
 
-    def __init__(self, *args, layers=1, **kwargs):
+    def __init__(self, *args, layers=1):
 
-        super().__init__(*args, **kwargs)
+        super().__init__(*args)
 
         self._layers = layers
 
-        if err := str(self):
-            Utils.log.warning(err)
+    def log(self):
+
+        if info := str(self):
+            logger.warning(info)
 
     def throw(self):
 
@@ -49,13 +42,15 @@ def catch_warning():
 
     """
 
+    # noinspection PyBroadException
     try:
         yield
     except Ignore as err:
+        err.log()
         if err.throw():
             raise err
-    except Exception as err:
-        Utils.log.warning(str(err))
+    except Exception as _:
+        logger.warning(traceback.format_exc())
 
 
 @contextmanager
@@ -66,30 +61,12 @@ def catch_error():
 
     """
 
+    # noinspection PyBroadException
     try:
         yield
     except Ignore as err:
+        err.log()
         if err.throw():
             raise err
-    except Exception as err:
-        Utils.log.exception(str(err))
-
-
-# 数据库只读限制异常
-class MySQLReadOnlyError(BaseError):
-    pass
-
-
-# 数据库客户端已销毁
-class MySQLClientDestroyed(BaseError):
-    pass
-
-
-# NTP校准异常
-class NTPCalibrateError(BaseError):
-    pass
-
-
-# Router异常
-class RouterError(BaseError):
-    pass
+    except Exception as _:
+        logger.error(traceback.format_exc())
