@@ -2,6 +2,8 @@
 
 __author__ = r'wsb310@gmail.com'
 
+import typing
+
 from .base import Utils, FuncWrapper
 
 
@@ -11,32 +13,28 @@ class EventDispatcher:
 
     def __init__(self):
 
-        self._observers = {}
+        self._observers: typing.Dict[str, FuncWrapper] = {}
 
-    def _gen_observer(self):
+    def _gen_observer(self) -> FuncWrapper:
 
         return FuncWrapper()
 
-    def dispatch(self, _type, *args, **kwargs):
+    def dispatch(self, _type: str, *args, **kwargs):
 
         if _type in self._observers:
             self._observers[_type](*args, **kwargs)
 
-    def add_listener(self, _type, _callable):
+    def add_listener(self, _type: str, _callable: typing.Callable) -> bool:
 
         Utils.log.debug(f'add event listener => type({_type}) function({id(_callable)})')
 
-        result = False
-
         if _type in self._observers:
-            result = self._observers[_type].add(_callable)
+            return self._observers[_type].add(_callable)
         else:
             observer = self._observers[_type] = self._gen_observer()
-            result = observer.add(_callable)
+            return observer.add(_callable)
 
-        return result
-
-    def remove_listener(self, _type, _callable):
+    def remove_listener(self, _type: str, _callable: typing.Callable) -> bool:
 
         Utils.log.debug(f'remove event listener => type({_type}) function({id(_callable)})')
 
