@@ -2,6 +2,8 @@
 
 __author__ = r'wsb310@gmail.com'
 
+import typing
+
 import qrcode
 
 from io import BytesIO
@@ -11,7 +13,7 @@ from qrcode.image.svg import SvgPathImage
 class QRCode:
 
     @staticmethod
-    def make(data, **kwargs):
+    def make(data: typing.Any, **kwargs) -> bytes:
 
         code_img = BytesIO()
 
@@ -20,7 +22,7 @@ class QRCode:
         return code_img.getvalue()
 
     @staticmethod
-    def make_svg(data, **kwargs):
+    def make_svg(data: typing.Any, **kwargs) -> str:
 
         code_img = BytesIO()
 
