@@ -2,18 +2,26 @@
 
 __author__ = r'wsb310@gmail.com'
 
+import typing
+
+from abc import ABCMeta, abstractmethod
+
 from .base import Utils
 from .interface import ContextManager
 
 
-class TransactionAbstract:
+class TransactionAbstract(metaclass=ABCMeta):
     """事务接口
     """
 
-    def __init__(self, *, commit_callback=None, rollback_callback=None):
+    def __init__(
+            self, *,
+            commit_callback: typing.Optional[typing.Callable] = None,
+            rollback_callback: typing.Optional[typing.Callable] = None
+    ):
 
-        self._commit_callbacks = []
-        self._rollback_callbacks = []
+        self._commit_callbacks: typing.List[typing.Callable] = []
+        self._rollback_callbacks: typing.List[typing.Callable] = []
 
         if commit_callback is not None:
             self._commit_callbacks.append(commit_callback)
@@ -28,35 +36,43 @@ class TransactionAbstract:
 
         self._commit_callbacks = self._rollback_callbacks = None
 
-    def add_commit_callback(self, _callable, *args, **kwargs):
+    def add_commit_callback(self, _callable: typing.Callable, *args, **kwargs):
 
-        if self._commit_callbacks is not None:
-            if args or kwargs:
-                self._commit_callbacks.append(
-                    Utils.func_partial(_callable, *args, **kwargs)
-                )
-            else:
-                self._commit_callbacks.append(_callable)
+        if self._commit_callbacks is None:
+            return
 
-    def add_rollback_callback(self, _callable, *args, **kwargs):
+        if args or kwargs:
+            self._commit_callbacks.append(
+                Utils.func_partial(_callable, *args, **kwargs)
+            )
+        else:
+            self._commit_callbacks.append(_callable)
 
-        if self._rollback_callbacks is not None:
-            if args or kwargs:
-                self._rollback_callbacks.append(
-                    Utils.func_partial(_callable, *args, **kwargs)
-                )
-            else:
-                self._rollback_callbacks.append(_callable)
+    def add_rollback_callback(self, _callable: typing.Callable, *args, **kwargs):
 
+        if self._rollback_callbacks is None:
+            return
+
+        if args or kwargs:
+            self._rollback_callbacks.append(
+                Utils.func_partial(_callable, *args, **kwargs)
+            )
+        else:
+            self._rollback_callbacks.append(_callable)
+
+    @abstractmethod
     def commit(self):
+        """
+        提交事务
+        """
 
-        raise NotImplementedError()
-
+    @abstractmethod
     def rollback(self):
+        """
+        回滚事务
+        """
 
-        raise NotImplementedError()
-
-    def bind(self, trx):
+    def bind(self, trx: 'TransactionAbstract'):
 
         self.add_commit_callback(trx.commit)
         self.add_rollback_callback(trx.rollback)
