@@ -2,9 +2,7 @@
 
 __author__ = r'wsb310@gmail.com'
 
-from uvicorn.workers import UvicornWorker
-
-from .fastapi.base import DEFAULT_HEADERS
+from uvicorn_worker import UvicornWorker
 
 
 DEFAULT_LOG_CONFIG = {
@@ -59,4 +57,4 @@ class Worker(UvicornWorker):
 
         super().__init__(*args, **kwargs)
 
-        self.config.headers.extend(DEFAULT_HEADERS)
+        self.config.server_header = False
\ No newline at end of file
